@@ -2,21 +2,18 @@
 GravMag: 3D imaging using the migration method on synthetic gravity data
 (more complex model + noisy data)
 """
-from fatiando import logger, gridder, mesher, gravmag, utils
+from fatiando import gridder, mesher, utils
+from fatiando.gravmag import prism, imaging
 from fatiando.vis import mpl, myv
 
-log = logger.get()
-log.info(logger.header())
-log.info(__doc__)
-
 # Make some synthetic gravity data from a simple prism model
-prisms = [mesher.Prism(-4000,0,-4000,-2000,2000,5000,{'density':1200}),
+model = [mesher.Prism(-4000,0,-4000,-2000,2000,5000,{'density':1200}),
           mesher.Prism(-1000,1000,-1000,1000,1000,7000,{'density':-800}),
           mesher.Prism(2000,4000,3000,4000,0,2000,{'density':600})]
 # Calculate on a scatter of points to show that migration doesn't need gridded
 # data
 xp, yp, zp = gridder.scatter((-6000, 6000, -6000, 6000), 1000, z=-10)
-gz = utils.contaminate(gravmag.prism.gz(xp, yp, zp, prisms), 0.1)
+gz = utils.contaminate(prism.gz(xp, yp, zp, model), 0.1)
 
 # Plot the data
 shape = (50, 50)
@@ -30,11 +27,11 @@ mpl.ylabel('North (km)')
 mpl.m2km()
 mpl.show()
 
-mesh = gravmag.imaging.migrate(xp, yp, zp, gz, 0, 10000, (30, 30, 30), power=0.8)
+mesh = imaging.migrate(xp, yp, zp, gz, 0, 10000, (30, 30, 30), power=0.8)
 
 # Plot the results
 myv.figure()
-myv.prisms(prisms, 'density', style='wireframe', linewidth=2)
+myv.prisms(model, 'density', style='wireframe', linewidth=2)
 myv.prisms(mesh, 'density', edges=False)
 axes = myv.axes(myv.outline())
 myv.wall_bottom(axes.axes.bounds)
